@@ -1,14 +1,30 @@
+from datetime import datetime, timedelta, timezone
+
 import numpy as np
 import pandas as pd
-from datetime import datetime, timedelta, timezone
 import pytest
+import pytz
 
 import vectorbt as vbt
 from vectorbt.utils.config import merge_dicts
+from vectorbt.utils.datetime_ import to_timezone
 
 seed = 42
 
 
+# ############# Global ############# #
+
+def setup_module():
+    vbt.settings.numba['check_func_suffix'] = True
+    vbt.settings.caching.enabled = False
+    vbt.settings.caching.whitelist = []
+    vbt.settings.caching.blacklist = []
+
+
+def teardown_module():
+    vbt.settings.reset()
+
+
 # ############# base.py ############# #
 
 
@@ -197,15 +213,15 @@ class TestData:
         )
         index2 = pd.DatetimeIndex(
             [
-                '2020-01-01 02:00:00',
-                '2020-01-02 02:00:00',
-                '2020-01-03 02:00:00',
-                '2020-01-04 02:00:00',
-                '2020-01-05 02:00:00'
+                '2020-01-01 00:00:00',
+                '2020-01-02 00:00:00',
+                '2020-01-03 00:00:00',
+                '2020-01-04 00:00:00',
+                '2020-01-05 00:00:00'
             ],
             freq='D',
-            tz=timezone(timedelta(hours=2))
-        )
+            tz=pytz.utc
+        ).tz_convert(to_timezone('Europe/Berlin'))
         pd.testing.assert_series_equal(
             MyData.download(0, shape=(5,), tz_localize='UTC', tz_convert='Europe/Berlin').data[0],
             pd.Series(
@@ -329,16 +345,16 @@ class TestData:
                 columns=pd.Int64Index([1], dtype='int64')
             )
         )
-        with pytest.raises(Exception) as e_info:
+        with pytest.raises(Exception):
             MyData.download([0, 1], shape=(5, 3), index_mask=index_mask, column_mask=column_mask,
                             missing_index='raise', missing_columns='nan')
-        with pytest.raises(Exception) as e_info:
+        with pytest.raises(Exception):
             MyData.download([0, 1], shape=(5, 3), index_mask=index_mask, column_mask=column_mask,
                             missing_index='nan', missing_columns='raise')
-        with pytest.raises(Exception) as e_info:
+        with pytest.raises(Exception):
             MyData.download([0, 1], shape=(5, 3), index_mask=index_mask, column_mask=column_mask,
                             missing_index='test', missing_columns='nan')
-        with pytest.raises(Exception) as e_info:
+        with pytest.raises(Exception):
             MyData.download([0, 1], shape=(5, 3), index_mask=index_mask, column_mask=column_mask,
                             missing_index='nan', missing_columns='test')
 
@@ -445,15 +461,15 @@ class TestData:
         )
         index2 = pd.DatetimeIndex(
             [
-                '2020-01-01 02:00:00',
-                '2020-01-02 02:00:00',
-                '2020-01-03 02:00:00',
-                '2020-01-04 02:00:00',
-                '2020-01-05 02:00:00'
+                '2020-01-01 00:00:00',
+                '2020-01-02 00:00:00',
+                '2020-01-03 00:00:00',
+                '2020-01-04 00:00:00',
+                '2020-01-05 00:00:00'
             ],
             freq='D',
-            tz=timezone(timedelta(hours=2))
-        )
+            tz=pytz.utc
+        ).tz_convert(to_timezone('Europe/Berlin'))
         pd.testing.assert_series_equal(
             MyData.download(0, shape=(5,), tz_localize='UTC', tz_convert='Europe/Berlin')
                 .update(tz_localize=None).data[0],
@@ -955,6 +971,71 @@ class TestData:
         assert MyData.download([0, 1], shape=(5, 3), columns=['feat0', 'feat1', 'feat2'])[['feat0']].wrapper == \
                MyData.download([0, 1], shape=(5, 1), columns=['feat0']).wrapper
 
+    def test_stats(self):
+        index_mask = vbt.symbol_dict({
+            0: [False, True, True, True, True],
+            1: [True, True, True, True, False]
+        })
+        column_mask = vbt.symbol_dict({
+            0: [False, True, True],
+            1: [True, True, False]
+        })
+        data = MyData.download(
+            [0, 1], shape=(5, 3), index_mask=index_mask, column_mask=column_mask,
+            missing_index='nan', missing_columns='nan', columns=['feat0', 'feat1', 'feat2'])
+
+        stats_index = pd.Index([
+            'Start', 'End', 'Period', 'Total Symbols', 'Null Counts: 0', 'Null Counts: 1'
+        ], dtype='object')
+        pd.testing.assert_series_equal(
+            data.stats(),
+            pd.Series([
+                pd.Timestamp('2020-01-01 00:00:00+0000', tz='UTC', freq='D'),
+                pd.Timestamp('2020-01-05 00:00:00+0000', tz='UTC', freq='D'),
+                pd.Timedelta('5 days 00:00:00'),
+                2, 2.3333333333333335, 2.3333333333333335
+            ],
+                index=stats_index,
+                name='agg_func_mean'
+            )
+        )
+        pd.testing.assert_series_equal(
+            data.stats(column='feat0'),
+            pd.Series([
+                pd.Timestamp('2020-01-01 00:00:00+0000', tz='UTC', freq='D'),
+                pd.Timestamp('2020-01-05 00:00:00+0000', tz='UTC', freq='D'),
+                pd.Timedelta('5 days 00:00:00'),
+                2, 5, 1
+            ],
+                index=stats_index,
+                name='feat0'
+            )
+        )
+        pd.testing.assert_series_equal(
+            data.stats(group_by=True),
+            pd.Series([
+                pd.Timestamp('2020-01-01 00:00:00+0000', tz='UTC', freq='D'),
+                pd.Timestamp('2020-01-05 00:00:00+0000', tz='UTC', freq='D'),
+                pd.Timedelta('5 days 00:00:00'),
+                2, 7, 7
+            ],
+                index=stats_index,
+                name='group'
+            )
+        )
+        pd.testing.assert_series_equal(
+            data['feat0'].stats(),
+            data.stats(column='feat0')
+        )
+        pd.testing.assert_series_equal(
+            data.replace(wrapper=data.wrapper.replace(group_by=True)).stats(),
+            data.stats(group_by=True)
+        )
+        stats_df = data.stats(agg_func=None)
+        assert stats_df.shape == (3, 6)
+        pd.testing.assert_index_equal(stats_df.index, data.wrapper.columns)
+        pd.testing.assert_index_equal(stats_df.columns, stats_index)
+
 
 # ############# updater.py ############# #
 
