@@ -93,38 +93,38 @@ def generate_gbm_paths(S0: float, mu: float, sigma: float, T: int, M: int, I: in
 class GBMData(SyntheticData):
     """`SyntheticData` for data generated using Geometric Brownian Motion (GBM).
 
-    ## Example
+    Usage:
+        * See the example under `BinanceData`.
 
-    See the example under `BinanceData`.
+        ```pycon
+        >>> import vectorbt as vbt
 
-    ```python-repl
-    >>> import vectorbt as vbt
+        >>> gbm_data = vbt.GBMData.download('GBM', start='2 hours ago', end='now', freq='1min', seed=42)
+        >>> gbm_data.get()
+        2021-05-02 14:14:15.182089+00:00    102.386605
+        2021-05-02 14:15:15.182089+00:00    101.554203
+        2021-05-02 14:16:15.182089+00:00    104.765771
+        ...                                        ...
+        2021-05-02 16:12:15.182089+00:00     51.614839
+        2021-05-02 16:13:15.182089+00:00     53.525376
+        2021-05-02 16:14:15.182089+00:00     55.615250
+        Freq: T, Length: 121, dtype: float64
 
-    >>> gbm_data = vbt.GBMData.download('GBM', start='2 hours ago', end='now', freq='1min', seed=42)
-    >>> gbm_data.get()
-    2021-05-02 14:14:15.182089+00:00    102.386605
-    2021-05-02 14:15:15.182089+00:00    101.554203
-    2021-05-02 14:16:15.182089+00:00    104.765771
-    ...                                        ...
-    2021-05-02 16:12:15.182089+00:00     51.614839
-    2021-05-02 16:13:15.182089+00:00     53.525376
-    2021-05-02 16:14:15.182089+00:00     55.615250
-    Freq: T, Length: 121, dtype: float64
+        >>> import time
+        >>> time.sleep(60)
 
-    >>> import time
-    >>> time.sleep(60)
-
-    >>> gbm_data = gbm_data.update()
-    >>> gbm_data.get()
-    2021-05-02 14:14:15.182089+00:00    102.386605
-    2021-05-02 14:15:15.182089+00:00    101.554203
-    2021-05-02 14:16:15.182089+00:00    104.765771
-    ...                                        ...
-    2021-05-02 16:13:15.182089+00:00     53.525376
-    2021-05-02 16:14:15.182089+00:00     51.082220
-    2021-05-02 16:15:15.182089+00:00     54.725304
-    Freq: T, Length: 122, dtype: float64
-    ```"""
+        >>> gbm_data = gbm_data.update()
+        >>> gbm_data.get()
+        2021-05-02 14:14:15.182089+00:00    102.386605
+        2021-05-02 14:15:15.182089+00:00    101.554203
+        2021-05-02 14:16:15.182089+00:00    104.765771
+        ...                                        ...
+        2021-05-02 16:13:15.182089+00:00     53.525376
+        2021-05-02 16:14:15.182089+00:00     51.082220
+        2021-05-02 16:15:15.182089+00:00     54.725304
+        Freq: T, Length: 122, dtype: float64
+        ```
+    """
 
     @classmethod
     def generate_symbol(cls,
@@ -184,64 +184,63 @@ class YFData(Data):
         how they want, add noise, return missing data points (see volume in the example below), etc.
         It's only used in vectorbt for demonstration purposes.
 
-    ## Example
+    Usage:
+        * Fetch the business day except the last 5 minutes of trading data, and then update with the missing 5 minutes:
 
-    Fetch the business day except the last 5 minutes of trading data, and then update with the missing 5 minutes:
+        ```pycon
+        >>> import vectorbt as vbt
 
-    ```python-repl
-    >>> import vectorbt as vbt
+        >>> yf_data = vbt.YFData.download(
+        ...     "TSLA",
+        ...     start='2021-04-12 09:30:00 -0400',
+        ...     end='2021-04-12 09:35:00 -0400',
+        ...     interval='1m'
+        ... )
+        >>> yf_data.get())
+                                         Open        High         Low       Close  \\
+        Datetime
+        2021-04-12 13:30:00+00:00  685.080017  685.679993  684.765015  685.679993
+        2021-04-12 13:31:00+00:00  684.625000  686.500000  684.010010  685.500000
+        2021-04-12 13:32:00+00:00  685.646790  686.820007  683.190002  686.455017
+        2021-04-12 13:33:00+00:00  686.455017  687.000000  685.000000  685.565002
+        2021-04-12 13:34:00+00:00  685.690002  686.400024  683.200012  683.715027
 
-    >>> yf_data = vbt.YFData.download(
-    ...     "TSLA",
-    ...     start='2021-04-12 09:30:00 -0400',
-    ...     end='2021-04-12 09:35:00 -0400',
-    ...     interval='1m'
-    ... )
-    >>> yf_data.get())
-                                     Open        High         Low       Close  \\
-    Datetime
-    2021-04-12 13:30:00+00:00  685.080017  685.679993  684.765015  685.679993
-    2021-04-12 13:31:00+00:00  684.625000  686.500000  684.010010  685.500000
-    2021-04-12 13:32:00+00:00  685.646790  686.820007  683.190002  686.455017
-    2021-04-12 13:33:00+00:00  686.455017  687.000000  685.000000  685.565002
-    2021-04-12 13:34:00+00:00  685.690002  686.400024  683.200012  683.715027
+                                   Volume  Dividends  Stock Splits
+        Datetime
+        2021-04-12 13:30:00+00:00       0          0             0
+        2021-04-12 13:31:00+00:00  152276          0             0
+        2021-04-12 13:32:00+00:00  168363          0             0
+        2021-04-12 13:33:00+00:00  129607          0             0
+        2021-04-12 13:34:00+00:00  134620          0             0
 
-                               Volume  Dividends  Stock Splits
-    Datetime
-    2021-04-12 13:30:00+00:00       0          0             0
-    2021-04-12 13:31:00+00:00  152276          0             0
-    2021-04-12 13:32:00+00:00  168363          0             0
-    2021-04-12 13:33:00+00:00  129607          0             0
-    2021-04-12 13:34:00+00:00  134620          0             0
+        >>> yf_data = yf_data.update(end='2021-04-12 09:40:00 -0400')
+        >>> yf_data.get()
+                                         Open        High         Low       Close  \\
+        Datetime
+        2021-04-12 13:30:00+00:00  685.080017  685.679993  684.765015  685.679993
+        2021-04-12 13:31:00+00:00  684.625000  686.500000  684.010010  685.500000
+        2021-04-12 13:32:00+00:00  685.646790  686.820007  683.190002  686.455017
+        2021-04-12 13:33:00+00:00  686.455017  687.000000  685.000000  685.565002
+        2021-04-12 13:34:00+00:00  685.690002  686.400024  683.200012  683.715027
+        2021-04-12 13:35:00+00:00  683.604980  684.340027  682.760071  684.135010
+        2021-04-12 13:36:00+00:00  684.130005  686.640015  683.333984  686.563904
+        2021-04-12 13:37:00+00:00  686.530029  688.549988  686.000000  686.635010
+        2021-04-12 13:38:00+00:00  686.593201  689.500000  686.409973  688.179993
+        2021-04-12 13:39:00+00:00  688.500000  689.347595  687.710022  688.070007
 
-    >>> yf_data = yf_data.update(end='2021-04-12 09:40:00 -0400')
-    >>> yf_data.get()
-                                     Open        High         Low       Close  \\
-    Datetime
-    2021-04-12 13:30:00+00:00  685.080017  685.679993  684.765015  685.679993
-    2021-04-12 13:31:00+00:00  684.625000  686.500000  684.010010  685.500000
-    2021-04-12 13:32:00+00:00  685.646790  686.820007  683.190002  686.455017
-    2021-04-12 13:33:00+00:00  686.455017  687.000000  685.000000  685.565002
-    2021-04-12 13:34:00+00:00  685.690002  686.400024  683.200012  683.715027
-    2021-04-12 13:35:00+00:00  683.604980  684.340027  682.760071  684.135010
-    2021-04-12 13:36:00+00:00  684.130005  686.640015  683.333984  686.563904
-    2021-04-12 13:37:00+00:00  686.530029  688.549988  686.000000  686.635010
-    2021-04-12 13:38:00+00:00  686.593201  689.500000  686.409973  688.179993
-    2021-04-12 13:39:00+00:00  688.500000  689.347595  687.710022  688.070007
-
-                               Volume  Dividends  Stock Splits
-    Datetime
-    2021-04-12 13:30:00+00:00       0          0             0
-    2021-04-12 13:31:00+00:00  152276          0             0
-    2021-04-12 13:32:00+00:00  168363          0             0
-    2021-04-12 13:33:00+00:00  129607          0             0
-    2021-04-12 13:34:00+00:00       0          0             0
-    2021-04-12 13:35:00+00:00  110500          0             0
-    2021-04-12 13:36:00+00:00  148384          0             0
-    2021-04-12 13:37:00+00:00  243851          0             0
-    2021-04-12 13:38:00+00:00  203569          0             0
-    2021-04-12 13:39:00+00:00   93308          0             0
-    ```
+                                   Volume  Dividends  Stock Splits
+        Datetime
+        2021-04-12 13:30:00+00:00       0          0             0
+        2021-04-12 13:31:00+00:00  152276          0             0
+        2021-04-12 13:32:00+00:00  168363          0             0
+        2021-04-12 13:33:00+00:00  129607          0             0
+        2021-04-12 13:34:00+00:00       0          0             0
+        2021-04-12 13:35:00+00:00  110500          0             0
+        2021-04-12 13:36:00+00:00  148384          0             0
+        2021-04-12 13:37:00+00:00  243851          0             0
+        2021-04-12 13:38:00+00:00  203569          0             0
+        2021-04-12 13:39:00+00:00   93308          0             0
+        ```
     """
 
     @classmethod
@@ -290,110 +289,110 @@ BinanceDataT = tp.TypeVar("BinanceDataT", bound="BinanceData")
 class BinanceData(Data):
     """`Data` for data coming from `python-binance`.
 
-    ## Example
+    Usage:
+        * Fetch the 1-minute data of the last 2 hours, wait 1 minute, and update:
 
-    Fetch the 1-minute data of the last 2 hours, wait 1 minute, and update:
+        ```pycon
+        >>> import vectorbt as vbt
 
-    ```python-repl
-    >>> import vectorbt as vbt
+        >>> binance_data = vbt.BinanceData.download(
+        ...     "BTCUSDT",
+        ...     start='2 hours ago UTC',
+        ...     end='now UTC',
+        ...     interval='1m'
+        ... )
+        >>> binance_data.get()
+        2021-05-02 14:47:20.478000+00:00 - 2021-05-02 16:47:00+00:00: : 1it [00:00,  3.42it/s]
+                                       Open      High       Low     Close     Volume  \\
+        Open time
+        2021-05-02 14:48:00+00:00  56867.44  56913.57  56857.40  56913.56  28.709976
+        2021-05-02 14:49:00+00:00  56913.56  56913.57  56845.94  56888.00  19.734841
+        2021-05-02 14:50:00+00:00  56888.00  56947.32  56879.78  56934.71  23.150163
+        ...                             ...       ...       ...       ...        ...
+        2021-05-02 16:45:00+00:00  56664.13  56666.77  56641.11  56644.03  40.852719
+        2021-05-02 16:46:00+00:00  56644.02  56663.43  56605.17  56605.18  27.573654
+        2021-05-02 16:47:00+00:00  56605.18  56657.55  56605.17  56627.12   7.719933
 
-    >>> binance_data = vbt.BinanceData.download(
-    ...     "BTCUSDT",
-    ...     start='2 hours ago UTC',
-    ...     end='now UTC',
-    ...     interval='1m'
-    ... )
-    >>> binance_data.get()
-    2021-05-02 14:47:20.478000+00:00 - 2021-05-02 16:47:00+00:00: : 1it [00:00,  3.42it/s]
-                                   Open      High       Low     Close     Volume  \\
-    Open time
-    2021-05-02 14:48:00+00:00  56867.44  56913.57  56857.40  56913.56  28.709976
-    2021-05-02 14:49:00+00:00  56913.56  56913.57  56845.94  56888.00  19.734841
-    2021-05-02 14:50:00+00:00  56888.00  56947.32  56879.78  56934.71  23.150163
-    ...                             ...       ...       ...       ...        ...
-    2021-05-02 16:45:00+00:00  56664.13  56666.77  56641.11  56644.03  40.852719
-    2021-05-02 16:46:00+00:00  56644.02  56663.43  56605.17  56605.18  27.573654
-    2021-05-02 16:47:00+00:00  56605.18  56657.55  56605.17  56627.12   7.719933
+                                                        Close time  Quote volume  \\
+        Open time
+        2021-05-02 14:48:00+00:00 2021-05-02 14:48:59.999000+00:00  1.633534e+06
+        2021-05-02 14:49:00+00:00 2021-05-02 14:49:59.999000+00:00  1.122519e+06
+        2021-05-02 14:50:00+00:00 2021-05-02 14:50:59.999000+00:00  1.317969e+06
+        ...                                                    ...           ...
+        2021-05-02 16:45:00+00:00 2021-05-02 16:45:59.999000+00:00  2.314579e+06
+        2021-05-02 16:46:00+00:00 2021-05-02 16:46:59.999000+00:00  1.561548e+06
+        2021-05-02 16:47:00+00:00 2021-05-02 16:47:59.999000+00:00  4.371848e+05
 
-                                                    Close time  Quote volume  \\
-    Open time
-    2021-05-02 14:48:00+00:00 2021-05-02 14:48:59.999000+00:00  1.633534e+06
-    2021-05-02 14:49:00+00:00 2021-05-02 14:49:59.999000+00:00  1.122519e+06
-    2021-05-02 14:50:00+00:00 2021-05-02 14:50:59.999000+00:00  1.317969e+06
-    ...                                                    ...           ...
-    2021-05-02 16:45:00+00:00 2021-05-02 16:45:59.999000+00:00  2.314579e+06
-    2021-05-02 16:46:00+00:00 2021-05-02 16:46:59.999000+00:00  1.561548e+06
-    2021-05-02 16:47:00+00:00 2021-05-02 16:47:59.999000+00:00  4.371848e+05
+                                   Number of trades  Taker base volume  \\
+        Open time
+        2021-05-02 14:48:00+00:00               991          13.771152
+        2021-05-02 14:49:00+00:00               816           5.981942
+        2021-05-02 14:50:00+00:00              1086          10.813757
+        ...                                     ...                ...
+        2021-05-02 16:45:00+00:00              1006          18.106933
+        2021-05-02 16:46:00+00:00               916          14.869411
+        2021-05-02 16:47:00+00:00               353           3.903321
 
-                               Number of trades  Taker base volume  \\
-    Open time
-    2021-05-02 14:48:00+00:00               991          13.771152
-    2021-05-02 14:49:00+00:00               816           5.981942
-    2021-05-02 14:50:00+00:00              1086          10.813757
-    ...                                     ...                ...
-    2021-05-02 16:45:00+00:00              1006          18.106933
-    2021-05-02 16:46:00+00:00               916          14.869411
-    2021-05-02 16:47:00+00:00               353           3.903321
+                                   Taker quote volume
+        Open time
+        2021-05-02 14:48:00+00:00        7.835391e+05
+        2021-05-02 14:49:00+00:00        3.402170e+05
+        2021-05-02 14:50:00+00:00        6.156418e+05
+        ...                                       ...
+        2021-05-02 16:45:00+00:00        1.025892e+06
+        2021-05-02 16:46:00+00:00        8.421173e+05
+        2021-05-02 16:47:00+00:00        2.210323e+05
 
-                               Taker quote volume
-    Open time
-    2021-05-02 14:48:00+00:00        7.835391e+05
-    2021-05-02 14:49:00+00:00        3.402170e+05
-    2021-05-02 14:50:00+00:00        6.156418e+05
-    ...                                       ...
-    2021-05-02 16:45:00+00:00        1.025892e+06
-    2021-05-02 16:46:00+00:00        8.421173e+05
-    2021-05-02 16:47:00+00:00        2.210323e+05
+        [120 rows x 10 columns]
 
-    [120 rows x 10 columns]
+        >>> import time
+        >>> time.sleep(60)
 
-    >>> import time
-    >>> time.sleep(60)
+        >>> binance_data = binance_data.update()
+        >>> binance_data.get()
+                                       Open      High       Low     Close     Volume  \\
+        Open time
+        2021-05-02 14:48:00+00:00  56867.44  56913.57  56857.40  56913.56  28.709976
+        2021-05-02 14:49:00+00:00  56913.56  56913.57  56845.94  56888.00  19.734841
+        2021-05-02 14:50:00+00:00  56888.00  56947.32  56879.78  56934.71  23.150163
+        ...                             ...       ...       ...       ...        ...
+        2021-05-02 16:46:00+00:00  56644.02  56663.43  56605.17  56605.18  27.573654
+        2021-05-02 16:47:00+00:00  56605.18  56657.55  56605.17  56625.76  14.615437
+        2021-05-02 16:48:00+00:00  56625.75  56643.60  56614.32  56623.01   5.895843
 
-    >>> binance_data = binance_data.update()
-    >>> binance_data.get()
-                                   Open      High       Low     Close     Volume  \\
-    Open time
-    2021-05-02 14:48:00+00:00  56867.44  56913.57  56857.40  56913.56  28.709976
-    2021-05-02 14:49:00+00:00  56913.56  56913.57  56845.94  56888.00  19.734841
-    2021-05-02 14:50:00+00:00  56888.00  56947.32  56879.78  56934.71  23.150163
-    ...                             ...       ...       ...       ...        ...
-    2021-05-02 16:46:00+00:00  56644.02  56663.43  56605.17  56605.18  27.573654
-    2021-05-02 16:47:00+00:00  56605.18  56657.55  56605.17  56625.76  14.615437
-    2021-05-02 16:48:00+00:00  56625.75  56643.60  56614.32  56623.01   5.895843
+                                                        Close time  Quote volume  \\
+        Open time
+        2021-05-02 14:48:00+00:00 2021-05-02 14:48:59.999000+00:00  1.633534e+06
+        2021-05-02 14:49:00+00:00 2021-05-02 14:49:59.999000+00:00  1.122519e+06
+        2021-05-02 14:50:00+00:00 2021-05-02 14:50:59.999000+00:00  1.317969e+06
+        ...                                                    ...           ...
+        2021-05-02 16:46:00+00:00 2021-05-02 16:46:59.999000+00:00  1.561548e+06
+        2021-05-02 16:47:00+00:00 2021-05-02 16:47:59.999000+00:00  8.276017e+05
+        2021-05-02 16:48:00+00:00 2021-05-02 16:48:59.999000+00:00  3.338702e+05
 
-                                                    Close time  Quote volume  \\
-    Open time
-    2021-05-02 14:48:00+00:00 2021-05-02 14:48:59.999000+00:00  1.633534e+06
-    2021-05-02 14:49:00+00:00 2021-05-02 14:49:59.999000+00:00  1.122519e+06
-    2021-05-02 14:50:00+00:00 2021-05-02 14:50:59.999000+00:00  1.317969e+06
-    ...                                                    ...           ...
-    2021-05-02 16:46:00+00:00 2021-05-02 16:46:59.999000+00:00  1.561548e+06
-    2021-05-02 16:47:00+00:00 2021-05-02 16:47:59.999000+00:00  8.276017e+05
-    2021-05-02 16:48:00+00:00 2021-05-02 16:48:59.999000+00:00  3.338702e+05
+                                   Number of trades  Taker base volume  \\
+        Open time
+        2021-05-02 14:48:00+00:00               991          13.771152
+        2021-05-02 14:49:00+00:00               816           5.981942
+        2021-05-02 14:50:00+00:00              1086          10.813757
+        ...                                     ...                ...
+        2021-05-02 16:46:00+00:00               916          14.869411
+        2021-05-02 16:47:00+00:00               912           7.778489
+        2021-05-02 16:48:00+00:00               308           2.358130
 
-                               Number of trades  Taker base volume  \\
-    Open time
-    2021-05-02 14:48:00+00:00               991          13.771152
-    2021-05-02 14:49:00+00:00               816           5.981942
-    2021-05-02 14:50:00+00:00              1086          10.813757
-    ...                                     ...                ...
-    2021-05-02 16:46:00+00:00               916          14.869411
-    2021-05-02 16:47:00+00:00               912           7.778489
-    2021-05-02 16:48:00+00:00               308           2.358130
+                                   Taker quote volume
+        Open time
+        2021-05-02 14:48:00+00:00        7.835391e+05
+        2021-05-02 14:49:00+00:00        3.402170e+05
+        2021-05-02 14:50:00+00:00        6.156418e+05
+        ...                                       ...
+        2021-05-02 16:46:00+00:00        8.421173e+05
+        2021-05-02 16:47:00+00:00        4.404362e+05
+        2021-05-02 16:48:00+00:00        1.335474e+05
 
-                               Taker quote volume
-    Open time
-    2021-05-02 14:48:00+00:00        7.835391e+05
-    2021-05-02 14:49:00+00:00        3.402170e+05
-    2021-05-02 14:50:00+00:00        6.156418e+05
-    ...                                       ...
-    2021-05-02 16:46:00+00:00        8.421173e+05
-    2021-05-02 16:47:00+00:00        4.404362e+05
-    2021-05-02 16:48:00+00:00        1.335474e+05
-
-    [121 rows x 10 columns]
-    ```"""
+        [121 rows x 10 columns]
+        ```
+    """
 
     @classmethod
     def download(cls: tp.Type[BinanceDataT],
@@ -546,50 +545,50 @@ class BinanceData(Data):
 class CCXTData(Data):
     """`Data` for data coming from `ccxt`.
 
-    ## Example
+    Usage:
+        * Fetch the 1-minute data of the last 2 hours, wait 1 minute, and update:
 
-    Fetch the 1-minute data of the last 2 hours, wait 1 minute, and update:
+        ```pycon
+        >>> import vectorbt as vbt
 
-    ```python-repl
-    >>> import vectorbt as vbt
+        >>> ccxt_data = vbt.CCXTData.download(
+        ...     "BTC/USDT",
+        ...     start='2 hours ago UTC',
+        ...     end='now UTC',
+        ...     timeframe='1m'
+        ... )
+        >>> ccxt_data.get()
+        2021-05-02 14:50:26.305000+00:00 - 2021-05-02 16:50:00+00:00: : 1it [00:00,  1.96it/s]
+                                       Open      High       Low     Close     Volume
+        Open time
+        2021-05-02 14:51:00+00:00  56934.70  56964.59  56910.00  56948.99  22.158319
+        2021-05-02 14:52:00+00:00  56948.99  56999.00  56940.04  56977.62  46.958464
+        2021-05-02 14:53:00+00:00  56977.61  56987.09  56882.98  56885.42  27.752200
+        ...                             ...       ...       ...       ...        ...
+        2021-05-02 16:48:00+00:00  56625.75  56643.60  56595.47  56596.01  15.452510
+        2021-05-02 16:49:00+00:00  56596.00  56664.14  56596.00  56640.35  12.777475
+        2021-05-02 16:50:00+00:00  56640.35  56675.82  56640.35  56670.65   6.882321
 
-    >>> ccxt_data = vbt.CCXTData.download(
-    ...     "BTC/USDT",
-    ...     start='2 hours ago UTC',
-    ...     end='now UTC',
-    ...     timeframe='1m'
-    ... )
-    >>> ccxt_data.get()
-    2021-05-02 14:50:26.305000+00:00 - 2021-05-02 16:50:00+00:00: : 1it [00:00,  1.96it/s]
-                                   Open      High       Low     Close     Volume
-    Open time
-    2021-05-02 14:51:00+00:00  56934.70  56964.59  56910.00  56948.99  22.158319
-    2021-05-02 14:52:00+00:00  56948.99  56999.00  56940.04  56977.62  46.958464
-    2021-05-02 14:53:00+00:00  56977.61  56987.09  56882.98  56885.42  27.752200
-    ...                             ...       ...       ...       ...        ...
-    2021-05-02 16:48:00+00:00  56625.75  56643.60  56595.47  56596.01  15.452510
-    2021-05-02 16:49:00+00:00  56596.00  56664.14  56596.00  56640.35  12.777475
-    2021-05-02 16:50:00+00:00  56640.35  56675.82  56640.35  56670.65   6.882321
+        [120 rows x 5 columns]
 
-    [120 rows x 5 columns]
+        >>> import time
+        >>> time.sleep(60)
 
-    >>> import time
-    >>> time.sleep(60)
+        >>> ccxt_data = ccxt_data.update()
+        >>> ccxt_data.get()
+                                       Open      High       Low     Close     Volume
+        Open time
+        2021-05-02 14:51:00+00:00  56934.70  56964.59  56910.00  56948.99  22.158319
+        2021-05-02 14:52:00+00:00  56948.99  56999.00  56940.04  56977.62  46.958464
+        2021-05-02 14:53:00+00:00  56977.61  56987.09  56882.98  56885.42  27.752200
+        ...                             ...       ...       ...       ...        ...
+        2021-05-02 16:49:00+00:00  56596.00  56664.14  56596.00  56640.35  12.777475
+        2021-05-02 16:50:00+00:00  56640.35  56689.99  56640.35  56678.33  14.610231
+        2021-05-02 16:51:00+00:00  56678.33  56688.99  56636.89  56653.42  11.647158
 
-    >>> ccxt_data = ccxt_data.update()
-    >>> ccxt_data.get()
-                                   Open      High       Low     Close     Volume
-    Open time
-    2021-05-02 14:51:00+00:00  56934.70  56964.59  56910.00  56948.99  22.158319
-    2021-05-02 14:52:00+00:00  56948.99  56999.00  56940.04  56977.62  46.958464
-    2021-05-02 14:53:00+00:00  56977.61  56987.09  56882.98  56885.42  27.752200
-    ...                             ...       ...       ...       ...        ...
-    2021-05-02 16:49:00+00:00  56596.00  56664.14  56596.00  56640.35  12.777475
-    2021-05-02 16:50:00+00:00  56640.35  56689.99  56640.35  56678.33  14.610231
-    2021-05-02 16:51:00+00:00  56678.33  56688.99  56636.89  56653.42  11.647158
-
-    [121 rows x 5 columns]
-    ```"""
+        [121 rows x 5 columns]
+        ```
+    """
 
     @classmethod
     def download_symbol(cls,
@@ -758,61 +757,55 @@ class CCXTData(Data):
         kwargs = merge_dicts(download_kwargs, kwargs)
         return self.download_symbol(symbol, **kwargs)
 
+
 class AlpacaData(Data):
-    """`Data` for data coming from `alpaca-trade-api`. 
-    Sign up for Alpaca API keys here: https://app.alpaca.markets/signup
+    """`Data` for data coming from `alpaca-trade-api`.
+
+    Sign up for Alpaca API keys under https://app.alpaca.markets/signup.
     
-    ## Example
+    Usage:
+        * Fetch the 1-minute data of the last 2 hours, wait 1 minute, and update:
 
-    Fetch the 1-minute data of the last 2 hours, wait 1 minute, and update:
+        ```pycon
+        >>> import vectorbt as vbt
 
-    ```python-repl
-    >>> import vectorbt as vbt
+        >>> alpaca_data = vbt.AlpacaData.download(
+        ...     "AAPL",
+        ...     start='2 hours ago UTC',
+        ...     end='15 minutes ago UTC',
+        ...     interval='1m'
+        ... )
+        >>> alpaca_data.get()
+                                    Open      High       Low     Close      Volume
+        timestamp
+        2021-12-27 14:04:00+00:00  177.0500  177.0500  177.0500  177.0500    1967
+        2021-12-27 14:05:00+00:00  177.0500  177.0500  177.0300  177.0500    3218
+        2021-12-27 14:06:00+00:00  177.0400  177.0400  177.0400  177.0400     873
+        ...                             ...       ...       ...       ...     ...
+        2021-12-27 15:46:00+00:00  177.9500  178.0000  177.8289  177.8850  162778
+        2021-12-27 15:47:00+00:00  177.8810  177.9600  177.8400  177.9515  123284
+        2021-12-27 15:48:00+00:00  177.9600  178.0500  177.9600  178.0100  159700
 
-    >>> alpaca_data = vbt.AlpacaData.download(
-    ...     "AAPL",
-    ...     start='2 hours ago UTC',
-    ...     end='15 minutes ago UTC',
-    ...     interval='1m'
-    ... )
-    >>> alpaca_data.get()
-                                Open      High       Low     Close      Volume
-    timestamp                                                                
-    2021-12-27 14:04:00+00:00  177.0500  177.0500  177.0500  177.0500    1967
-    2021-12-27 14:05:00+00:00  177.0500  177.0500  177.0300  177.0500    3218
-    2021-12-27 14:06:00+00:00  177.0400  177.0400  177.0400  177.0400     873
-    2021-12-27 14:07:00+00:00  177.0399  177.0400  177.0300  177.0400    1100
-    2021-12-27 14:08:00+00:00  177.0400  177.0400  176.9700  176.9900   19943
-    ...                             ...       ...       ...       ...     ...
-    2021-12-27 15:44:00+00:00  178.0000  178.0079  177.9311  177.9710  106395
-    2021-12-27 15:45:00+00:00  177.9700  178.0564  177.9430  177.9600  153325
-    2021-12-27 15:46:00+00:00  177.9500  178.0000  177.8289  177.8850  162778
-    2021-12-27 15:47:00+00:00  177.8810  177.9600  177.8400  177.9515  123284
-    2021-12-27 15:48:00+00:00  177.9600  178.0500  177.9600  178.0100  159700
+        [105 rows x 5 columns]
 
-    [105 rows x 5 columns]
+        >>> import time
+        >>> time.sleep(60)
 
-    >>> import time
-    >>> time.sleep(60)
+        >>> alpaca_data = alpaca_data.update()
+        >>> alpaca_data.get()
+                                    Open      High       Low     Close      Volume
+        timestamp
+        2021-12-27 14:04:00+00:00  177.0500  177.0500  177.0500  177.0500    1967
+        2021-12-27 14:05:00+00:00  177.0500  177.0500  177.0300  177.0500    3218
+        2021-12-27 14:06:00+00:00  177.0400  177.0400  177.0400  177.0400     873
+        ...                             ...       ...       ...       ...     ...
+        2021-12-27 15:47:00+00:00  177.8810  177.9600  177.8400  177.9515  123284
+        2021-12-27 15:48:00+00:00  177.9600  178.0500  177.9600  178.0100  159700
+        2021-12-27 15:49:00+00:00  178.0100  178.0700  177.9700  178.0650  185037
 
-    >>> alpaca_data = alpaca_data.update()
-    >>> alpaca_data.get()
-                                Open      High       Low     Close      Volume
-    timestamp                                                                
-    2021-12-27 14:04:00+00:00  177.0500  177.0500  177.0500  177.0500    1967
-    2021-12-27 14:05:00+00:00  177.0500  177.0500  177.0300  177.0500    3218
-    2021-12-27 14:06:00+00:00  177.0400  177.0400  177.0400  177.0400     873
-    2021-12-27 14:07:00+00:00  177.0399  177.0400  177.0300  177.0400    1100
-    2021-12-27 14:08:00+00:00  177.0400  177.0400  176.9700  176.9900   19943
-    ...                             ...       ...       ...       ...     ...
-    2021-12-27 15:45:00+00:00  177.9700  178.0564  177.9430  177.9600  153325
-    2021-12-27 15:46:00+00:00  177.9500  178.0000  177.8289  177.8850  162778
-    2021-12-27 15:47:00+00:00  177.8810  177.9600  177.8400  177.9515  123284
-    2021-12-27 15:48:00+00:00  177.9600  178.0500  177.9600  178.0100  159700
-    2021-12-27 15:49:00+00:00  178.0100  178.0700  177.9700  178.0650  185037
-
-    [106 rows x 5 columns]
-    ```"""
+        [106 rows x 5 columns]
+        ```
+    """
 
     @classmethod
     def download_symbol(cls,
@@ -828,9 +821,13 @@ class AlpacaData(Data):
 
         Args:
             symbol (str): Symbol.
-            timeframe (str): Timeframe of data. Must be integer multiple of 'm' (minute), 'h' (hour) or 'd' (day). i.e. '15m' 
-                Note: Data from the latest 15 minutes is not available with a free data plan.
-                See: https://alpaca.markets/data
+            timeframe (str): Timeframe of data.
+
+                Must be integer multiple of 'm' (minute), 'h' (hour) or 'd' (day). i.e. '15m'.
+                See https://alpaca.markets/data.
+
+                !!! note
+                    Data from the latest 15 minutes is not available with a free data plan.
 
             start (any): Start datetime.
 
@@ -839,38 +836,40 @@ class AlpacaData(Data):
 
                 See `vectorbt.utils.datetime_.to_tzaware_datetime`.
             adjustment (str): Specifies the corporate action adjustment for the stocks. 
-                Enum: `raw`, `split`, `dividend` or `all`.
+
+                Allowed are `raw`, `split`, `dividend` or `all`.
             limit (int): The maximum number of returned items.
             exchange (str): For crypto symbols. Which exchange you wish to retrieve data from.
-                Enum: `FTX`, `ERSX`, `CBSE`
+
+                Allowed are `FTX`, `ERSX`, `CBSE`
 
         For defaults, see `data.alpaca` in `vectorbt._settings.settings`.
         """
         from vectorbt._settings import settings
         from alpaca_trade_api.rest import TimeFrameUnit, TimeFrame, REST
-        
+
         alpaca_cfg = settings['data']['alpaca']
-        
+
         client_kwargs = dict()
         for k in get_func_kwargs(REST):
             if k in kwargs:
                 client_kwargs[k] = kwargs.pop(k)
 
         client_kwargs = merge_dicts(alpaca_cfg, client_kwargs)
-        
+
         client = REST(**client_kwargs)
 
         _timeframe_units = {'d': TimeFrameUnit.Day, 'h': TimeFrameUnit.Hour, 'm': TimeFrameUnit.Minute}
 
         if len(timeframe) < 2:
             raise ValueError("invalid timeframe")
-            
+
         amount_str = timeframe[:-1]
         unit_str = timeframe[-1]
 
         if not amount_str.isnumeric() or unit_str not in _timeframe_units:
             raise ValueError("invalid timeframe")
-        
+
         amount = int(amount_str)
         unit = _timeframe_units[unit_str]
 
@@ -879,31 +878,41 @@ class AlpacaData(Data):
         start_ts = to_tzaware_datetime(start, tz=get_utc_tz()).isoformat()
         end_ts = to_tzaware_datetime(end, tz=get_utc_tz()).isoformat()
 
-        
         def _is_crypto_symbol(symbol):
             return len(symbol) == 6 and "USD" in symbol
 
         if _is_crypto_symbol(symbol):
-            df = client.get_crypto_bars(symbol=symbol,
-                                    timeframe=_timeframe,
-                                    start=start_ts,
-                                    end=end_ts,
-                                    limit=limit,
-                                    exchanges=exchange).df
+            df = client.get_crypto_bars(
+                symbol=symbol,
+                timeframe=_timeframe,
+                start=start_ts,
+                end=end_ts,
+                limit=limit,
+                exchanges=exchange
+            ).df
         else:
-            df = client.get_bars(symbol=symbol, 
-                                timeframe=_timeframe,
-                                start=start_ts,
-                                end=end_ts,
-                                adjustment=adjustment, 
-                                limit=limit).df
-        
+            df = client.get_bars(
+                symbol=symbol,
+                timeframe=_timeframe,
+                start=start_ts,
+                end=end_ts,
+                adjustment=adjustment,
+                limit=limit
+            ).df
+
         # filter for OHLCV
         # remove extra columns
         df.drop(['trade_count', 'vwap'], axis=1, errors='ignore', inplace=True)
 
         # capitalize
-        df.rename(columns={'open': 'Open', 'high': 'High', 'low': 'Low', 'close': 'Close', 'volume': 'Volume', 'exchange':'Exchange'}, inplace=True)
+        df.rename(columns={
+            'open': 'Open',
+            'high': 'High',
+            'low': 'Low',
+            'close': 'Close',
+            'volume': 'Volume',
+            'exchange': 'Exchange'
+        }, inplace=True)
 
         df['Open'] = df['Open'].astype(float)
         df['High'] = df['High'].astype(float)
@@ -913,8 +922,6 @@ class AlpacaData(Data):
 
         return df
 
-
-
     def update_symbol(self, symbol: str, **kwargs) -> tp.Frame:
         """Update the symbol.
 
@@ -923,4 +930,4 @@ class AlpacaData(Data):
         download_kwargs['start'] = self.data[symbol].index[-1]
         download_kwargs['show_progress'] = False
         kwargs = merge_dicts(download_kwargs, kwargs)
-        return self.download_symbol(symbol, **kwargs)
\ No newline at end of file
+        return self.download_symbol(symbol, **kwargs)
